@@ -140,7 +140,7 @@ public:
 	{
 		return subs_one_level(m, options);
 	} // overwrites basic::subs() for performance reasons
-	ex normal(exmap & repl, exmap & rev_lookup, int level = 0) const override;
+	ex normal(exmap & repl, exmap & rev_lookup, int level = 0, unsigned options = 0) const override;
 	ex to_rational(exmap & repl) const override;
 	ex to_polynomial(exmap & repl) const override;
 	numeric integer_content() const override;
@@ -184,7 +184,6 @@ public:
 	const numeric inverse() const;
 	const numeric step() const;
 	int csgn() const;
-	int compare(const numeric &other) const;
 	bool is_equal(const numeric &other) const;
 	bool is_zero() const;
 	bool is_positive() const;
@@ -230,6 +229,8 @@ public:
 
 	const numeric exp() const;
 	const numeric log() const;
+	const numeric log(const numeric &b) const;
+	const numeric ratlog(const numeric &b, bool& israt) const;
 	const numeric sin() const;
 	const numeric cos() const;
 	const numeric tan() const;
@@ -243,12 +244,12 @@ public:
 	const numeric asinh() const;
 	const numeric acosh() const;
 	const numeric atanh() const;
-	const numeric Li2() const;
 	const numeric Li2(const numeric &n, PyObject* parent) const;
 	const numeric zeta() const;
 	const numeric stieltjes() const;
 	const numeric lgamma() const;
-	const numeric tgamma() const;
+	const numeric tgamma(PyObject* parent) const;
+	const numeric rgamma(PyObject* parent) const;
 	const numeric psi() const;
 	const numeric psi(const numeric &n) const;
 	const numeric factorial() const;
@@ -304,6 +305,7 @@ void coerce(numeric& new_left, numeric& new_right, const numeric& left, const nu
 
 const numeric exp(const numeric &x);
 const numeric log(const numeric &x);
+const numeric log(const numeric &x, const numeric &b);
 const numeric sin(const numeric &x);
 const numeric cos(const numeric &x);
 const numeric tan(const numeric &x);
@@ -322,7 +324,8 @@ const numeric Li2(const numeric &x, const numeric &n, PyObject* parent);
 const numeric stieltjes(const numeric &x);
 const numeric zeta(const numeric &x);
 const numeric lgamma(const numeric &x);
-const numeric tgamma(const numeric &x);
+const numeric tgamma(const numeric &x, PyObject* parent=nullptr);
+const numeric rgamma(const numeric &x, PyObject* parent);
 const numeric psi(const numeric &x);
 const numeric psi(const numeric &n, const numeric &x);
 const numeric factorial(const numeric &n);
